@@ -1,5 +1,5 @@
-import typing
 import inspect
+import typing
 from abc import ABC, abstractmethod
 from collections import OrderedDict
 from enum import Enum
@@ -17,21 +17,18 @@ class AlgorithmProperty:
     """
     This class is used to verbose describe algorithm parameters
 
-    :param name: name of parameter used in code
-    :param user_name: name presented to user in interface
+    :param str name: name of parameter used in code
+    :param str user_name: name presented to user in interface
     :param default_value: initial value which be used during interface generation
-    :param help_text: toll tip presented to user when keep mouse over widget
-    :type name: str
-    :type user_name: str
+    :param str help_text: toll tip presented to user when keep mouse over widget
     :type value_type: type
-    :type default_value: typing.Union[object, str, int, float]
     """
 
     def __init__(
         self,
         name: str,
         user_name: str,
-        default_value,
+        default_value: typing.Union[str, int, float, object],
         options_range=None,
         single_steep=None,
         possible_values=None,
@@ -107,7 +104,7 @@ class AlgorithmDescribeBase(ABC):
 
     @classmethod
     def get_fields_dict(cls) -> typing.Dict[str, AlgorithmProperty]:
-        return dict([(v.name, v) for v in cls.get_fields() if isinstance(v, AlgorithmProperty)])
+        return {v.name: v for v in cls.get_fields() if isinstance(v, AlgorithmProperty)}
 
     @classmethod
     def get_default_values(cls):
@@ -133,7 +130,10 @@ def is_static(fun):
     return False
 
 
-class Register(OrderedDict):
+AlgorithmType = typing.TypeVar("AlgorithmType", bound=type(AlgorithmDescribeBase))
+
+
+class Register(OrderedDict, typing.Generic[AlgorithmType]):
     """
     Dict used for register :class:`.AlgorithmDescribeBase` classes.
     All registers from `PartSeg.PartSegCore.register` are this
@@ -142,7 +142,7 @@ class Register(OrderedDict):
     :param methods: list of method which should be instance method
     """
 
-    def __init__(self, *args, class_methods=None, methods=None, suggested_base_class=None, **kwargs):
+    def __init__(self, *args: AlgorithmType, class_methods=None, methods=None, suggested_base_class=None, **kwargs):
         """
         :param class_methods: list of method which should be class method
         :param methods: list of method which should be instance method
@@ -157,6 +157,10 @@ class Register(OrderedDict):
         for el in args:
             self.register(el)
 
+    def values(self) -> typing.Iterable[AlgorithmType]:
+        # noinspection PyTypeChecker
+        return super().values()
+
     def __eq__(self, other):
         return (
             super().__eq__(other)
@@ -166,10 +170,10 @@ class Register(OrderedDict):
             and self.suggested_base_class == other.suggested_base_class
         )
 
-    def __getitem__(self, item):
+    def __getitem__(self, item) -> AlgorithmType:
         return super().__getitem__(item)
 
-    def register(self, value: typing.Type[AlgorithmDescribeBase], replace=False):
+    def register(self, value: AlgorithmType, replace=False):
         """
         Function for registering :class:`.AlgorithmDescribeBase` based algorithms
         :param value: algorithm to register
@@ -194,7 +198,7 @@ class Register(OrderedDict):
         if is_class and not (inspect.ismethod(fun) or is_static(fun)):
             raise ValueError(f"Class {ob} need to define classmethod {function_name}")
 
-    def __setitem__(self, key, value):
+    def __setitem__(self, key: str, value: AlgorithmType):
         if not issubclass(value, AlgorithmDescribeBase):
             raise ValueError(
                 f"Class {value} need to inherit from " f"{AlgorithmDescribeBase.__module__}.AlgorithmDescribeBase"
@@ -223,7 +227,7 @@ class Register(OrderedDict):
         super().__setitem__(key, value)
 
 
-class SegmentationProfile(object):
+class ROIExtractionProfile:
     """
 
     :ivar str ~.name: name for segmentation profile
@@ -243,13 +247,13 @@ class SegmentationProfile(object):
             return str(self)
         if self.name == "" or self.name == "Unknown":
             return (
-                "Segmentation profile\nAlgorithm: "
+                "ROI extraction profile\nAlgorithm: "
                 + self.algorithm
                 + "\n"
                 + self._pretty_print(self.values, algorithm.get_fields_dict())
             )
         return (
-            "Segmentation profile name: "
+            "ROI extraction profile name: "
             + self.name
             + "\nAlgorithm: "
             + self.algorithm
@@ -299,4 +303,4 @@ class SegmentationProfile(object):
         )
 
     def __repr__(self):
-        return f"SegmentationProfile(name={self.name}, algorithm={self.algorithm}, values={self.values})"
+        return f"SegmentationProfile(name={self.name}, algorithm={repr(self.algorithm)}, values={self.values})"
