@@ -11,11 +11,12 @@ from tarfile import TarFile, TarInfo
 
 import imageio
 import numpy as np
+import tifffile
 
 from PartSegCore.json_hooks import ProfileDict, profile_hook
 from PartSegImage import ImageWriter
 
-from .algorithm_describe_base import AlgorithmDescribeBase, AlgorithmProperty, SegmentationProfile
+from .algorithm_describe_base import AlgorithmDescribeBase, AlgorithmProperty, ROIExtractionProfile
 from .class_generator import BaseSerializableClass
 from .mask_create import MaskProperty
 from .project_info import ProjectInfoBase
@@ -107,6 +108,16 @@ class SaveBase(AlgorithmDescribeBase, ABC):
     def need_mask(cls):
         return False
 
+    @classmethod
+    def get_extensions(cls) -> typing.List[str]:
+        match = re.match(r".*\((.*)\)", cls.get_name())
+        if match is None:
+            raise ValueError(f"No extensions found in {cls.get_name()}")
+        extensions = match.group(1).split(" ")
+        if not all(x.startswith("*.") for x in extensions):
+            raise ValueError(f"Error with parsing extensions in {cls.get_name()}")
+        return [x[1:] for x in extensions]
+
 
 class LoadBase(AlgorithmDescribeBase, ABC):
     need_functions = [
@@ -200,7 +211,7 @@ class UpdateLoadedMetadataBase:
     def recursive_update(cls, data):
         if isinstance(data, (tuple, list)):
             return type(data)([cls.recursive_update(x) for x in data])
-        if isinstance(data, SegmentationProfile):
+        if isinstance(data, ROIExtractionProfile):
             return cls.update_segmentation_profile(data)
         if isinstance(data, Enum):
             return cls.update_enum(data)
@@ -229,7 +240,7 @@ class UpdateLoadedMetadataBase:
         return dkt
 
     @classmethod
-    def update_segmentation_profile(cls, profile_data: SegmentationProfile) -> SegmentationProfile:
+    def update_segmentation_profile(cls, profile_data: ROIExtractionProfile) -> ROIExtractionProfile:
         for key in list(profile_data.values.keys()):
             item = profile_data.values[key]
             if isinstance(item, Enum):
@@ -320,6 +331,10 @@ class SaveMaskAsTiff(SaveBase):
     def get_fields(cls):
         return []
 
+    @classmethod
+    def need_mask(cls):
+        return True
+
     @classmethod
     def save(
         cls,
@@ -365,3 +380,65 @@ class SaveScreenshot(SaveBase):
     @classmethod
     def get_fields(cls) -> typing.List[typing.Union[AlgorithmProperty, str]]:
         return []
+
+
+class SaveROIAsTIFF(SaveBase):
+    @classmethod
+    def get_name(cls):
+        return "ROI as tiff (*.tiff *.tif)"
+
+    @classmethod
+    def get_short_name(cls):
+        return "roi_tiff"
+
+    @classmethod
+    def get_fields(cls):
+        return []
+
+    @classmethod
+    def save(
+        cls,
+        save_location: typing.Union[str, BytesIO, Path],
+        project_info,
+        parameters: dict,
+        range_changed=None,
+        step_changed=None,
+    ):
+        segmentation = project_info.roi
+        segmentation_max = segmentation.max()
+        if segmentation_max < 2 ** 8 - 1:
+            segmentation = segmentation.astype(np.uint8)
+        elif segmentation_max < 2 ** 16 - 1:
+            segmentation = segmentation.astype(np.uint16)
+        tifffile.imsave(save_location, segmentation)
+
+
+class SaveROIAsNumpy(SaveBase):
+    @classmethod
+    def get_name(cls):
+        return "ROI as numpy (*.npy)"
+
+    @classmethod
+    def get_short_name(cls):
+        return "ROI_numpy"
+
+    @classmethod
+    def get_fields(cls):
+        return []
+
+    @classmethod
+    def save(
+        cls,
+        save_location: typing.Union[str, BytesIO, Path],
+        project_info,
+        parameters: dict = None,
+        range_changed=None,
+        step_changed=None,
+    ):
+        segmentation = project_info.roi
+        segmentation_max = segmentation.max()
+        if segmentation_max < 2 ** 8 - 1:
+            segmentation = segmentation.astype(np.uint8)
+        elif segmentation_max < 2 ** 16 - 1:
+            segmentation = segmentation.astype(np.uint16)
+        np.save(save_location, segmentation)
